# Cognitive Services Form Recognizer SDK

> see https://aka.ms/autorest

Configuration for generating Form Recognizer SDK.

The current release is `release_2_1`.

``` yaml

tag: release_2_1
add-credentials: true
openapi-type: data-plane
```

# Releases

### Release 2022-06-30-preview
These settings apply only when `--tag=2022-06-30-preview` is specified on the command line.
``` yaml $(tag) == '2022-06-30-preview'
input-file:
  - preview/2022-06-30-preview/FormRecognizer.json

```
### Release 2022-01-30-preview
These settings apply only when `--tag=2022-01-30-preview` is specified on the command line.
``` yaml $(tag) == '2022-01-30-preview'
input-file:
  - preview/2022-01-30-preview/FormRecognizer.json
```

### Release 2021-09-30-preview
These settings apply only when `--tag=2021-09-30-preview` is specified on the command line.
``` yaml $(tag) == '2021-09-30-preview'
input-file:
  - preview/2021-09-30-preview/FormRecognizer.json
```

### Release 2.1
These settings apply only when `--tag=release_2_1` is specified on the command line.
``` yaml $(tag) == 'release_2_1'
input-file:
  - stable/v2.1/FormRecognizer.json
```

### Release 2.1-preview.3
These settings apply only when `--tag=release_2_1_preview.3` is specified on the command line.
``` yaml $(tag) == 'release_2_1_preview.3'
input-file:
  - preview/v2.1-preview.3/FormRecognizer.json
```

### Release 2.1-preview.2
These settings apply only when `--tag=release_2_1_preview.2` is specified on the command line.
``` yaml $(tag) == 'release_2_1_preview.2'
input-file: 
  - preview/v2.1-preview.2/FormRecognizer.json
```

### Release 2.1-preview.1
These settings apply only when `--tag=release_2_1_preview.1` is specified on the command line.
``` yaml $(tag) == 'release_2_1_preview.1'
input-file: 
  - preview/v2.1-preview.1/FormRecognizer.json
```

### Release 2.0
These settings apply only when `--tag=release_2_0` is specified on the command line.

``` yaml $(tag) == 'release_2_0'
input-file: 
  - stable/v2.0/FormRecognizer.json
```

### Release 2.0-preview
These settings apply only when `--tag=release_2_0_preview` is specified on the command line.

``` yaml $(tag) == 'release_2_0_preview'
input-file: 
  - preview/v2.0/FormRecognizer.json
```


### Release 1.0
These settings apply only when `--tag=release_1_0` is specified on the command line.

``` yaml $(tag) == 'release_1_0'
input-file: 
  - preview/v1.0/FormRecognizer.json
  - preview/v1.0/FormRecognizerReceipt.json
  - preview/v1.0/FormRecognizerReceiptOcr.json
```


## Suppression
``` yaml
directive:
  - suppress: PATTERN
    from: FormRecognizer/preview/2021-09-30-preview/FormRecognizer.json
    where: $.parameters.modelId
    reason: Bug in example validation
  - suppress: LongRunningResponseStatusCode
    from: FormRecognizer/preview/2021-09-30-preview/FormRecognizer.json
    reason: Latest guidelines recommend 202 for long running operations.
  - suppress: ValidFormats
    from: FormRecognizer/preview/2021-09-30-preview/FormRecognizer.json
    where: 
    - $.definitions.UrlContentSource.format
    - $.definitions.AzureBlobContentSource.properties.containerUrl.format
    - $.definitions.DocumentField.properties.valueTime.format
    reason: uri and time are valid formats in JsonSchema/Swagger and does not affect SDK.
  - suppress: AvoidNestedProperties
    from: FormRecognizer/preview/2021-09-30-preview/FormRecognizer.json
    where: $.definitions.DocumentFieldSchema.properties.properties
    reason: Intentionally trying to mimic JsonSchema with recursion.
```


## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-net-track2
```


## CSharp Settings
These settings apply only when `--csharp` is specified on the command line.
``` yaml $(csharp)
csharp:
  sync-methods: None
  license-header: MICROSOFT_MIT_NO_VERSION
  azure-arm: false
  namespace: Microsoft.Azure.CognitiveServices.FormRecognizer
  output-folder: $(csharp-sdks-folder)/CognitiveServices/FormRecognizer/src/Generated
  title: "FormRecognizerClient"
  clear-output-folder: true
```

## Go

See configuration in [readme.go.md](./readme.go.md)

## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
java:
  azure-arm: true
  namespace: com.microsoft.azure.cognitiveservices.formrecognizer
  license-header: MICROSOFT_MIT_NO_CODEGEN
  payload-flattening-threshold: 1
  output-folder: $(azure-libraries-for-java-folder)/cognitiveservices/data-plane/vision/formrecognizer
  with-optional-parameters: true
  with-single-async-method: true
```

## Multi-API/Profile support for AutoRest v3 generators 

AutoRest V3 generators require the use of `--tag=all-api-versions` to select api files.

This block is updated by an automatic script. Edits may be lost!

``` yaml $(tag) == 'all-api-versions' /* autogenerated */
# include the azure profile definitions from the standard location
require: $(this-folder)/../../../../profiles/readme.md

# all the input files across all versions
input-file:
  - $(this-folder)/preview/v2.1-preview.1/FormRecognizer.json
  - $(this-folder)/stable/v2.0/FormRecognizer.json
  - $(this-folder)/preview/v2.0/FormRecognizer.json
  - $(this-folder)/preview/v1.0/FormRecognizer.json
  - $(this-folder)/preview/v1.0/FormRecognizerReceipt.json
  - $(this-folder)/preview/v1.0/FormRecognizerReceiptOcr.json

```

If there are files that should not be in the `all-api-versions` set, 
uncomment the  `exclude-file` section below and add the file paths.

``` yaml $(tag) == 'all-api-versions'
#exclude-file: 
#  - $(this-folder)/Microsoft.Example/stable/2010-01-01/somefile.json
```
