# Cognitive Services LUIS SDKs

> see https://aka.ms/autorest

Configuration for generating LUIS Runtime SDK.

``` yaml
tag: runtime_3_0
add-credentials: true
openapi-type: data-plane
```

The current release for the Runtime Endpoint is `runtime_3_0`.

# Releases

## Runtime 2.0
These settings apply only when `--tag=runtime_2_0` is specified on the command line.

``` yaml $(tag) == 'runtime_2_0'
input-file: stable/v2.0/LUIS-Runtime.json

# remove Resolve2 from code-generation (since the POST and GET operations are functionally identical)
directive:
  remove-operation: Prediction_Resolve2
```

## Runtime 3.0
These settings apply only when `--tag=runtime_3_0` is specified on the command line.

``` yaml $(tag) == 'runtime_3_0'
input-file: stable/v3.0/LUIS-Runtime.json

# remove the GET APIs from code-generation (since the POST and GET operations are functionally identical)
directive:
  - remove-operation: Prediction_GetSlotPredictionGET
  - remove-operation: Prediction_GetVersionPredictionGET
```

---
# Code Generation

### CSharp
These settings apply only when `--csharp` is specified on the command line.
``` yaml $(csharp)
csharp:
  sync-methods: None
  license-header: MICROSOFT_MIT_NO_VERSION
  azure-arm: false
  namespace: Microsoft.Azure.CognitiveServices.Language.LUIS.Runtime
  output-folder: $(csharp-sdks-folder)/CognitiveServices/Language.LUIS.Runtime/src/Generated
  clear-output-folder: true

# csharp has support for modelAsExtensible now; replace modelAsString with that.
directive:
  from: swagger-document
  where: $..['x-ms-enum']
  transform: >
    if( $['modelAsString'] ) {
      $['modelAsExtensible'] = true;
      $['modelAsString'] = false;
    }
```

## Go

See configuration in [readme.go.md](./readme.go.md)

## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
java:
  override-client-name: LuisRuntimeAPI
  azure-arm: true
  namespace: com.microsoft.azure.cognitiveservices.language.luis.runtime
  license-header: MICROSOFT_MIT_NO_CODEGEN
  payload-flattening-threshold: 1
  output-folder: $(azure-libraries-for-java-folder)/cognitiveservices/data-plane/language/luis/runtime
  with-optional-parameters: true
  with-single-async-method: true
```

## Multi-API/Profile support for AutoRest v3 generators 

AutoRest V3 generators require the use of `--tag=all-api-versions` to select api files.

This block is updated by an automatic script. Edits may be lost!

``` yaml $(tag) == 'all-api-versions' /* autogenerated */
# include the azure profile definitions from the standard location
require: $(this-folder)/../../../../../profiles/readme.md

# all the input files across all versions
input-file:
  - $(this-folder)/stable/v2.0/LUIS-Runtime.json
  - $(this-folder)/stable/v3.0/LUIS-Runtime.json

```

If there are files that should not be in the `all-api-versions` set, 
uncomment the  `exclude-file` section below and add the file paths.

``` yaml $(tag) == 'all-api-versions'
#exclude-file: 
#  - $(this-folder)/Microsoft.Example/stable/2010-01-01/somefile.json
```

