# DataLakeAnalytics

> see https://aka.ms/autorest

This is the AutoRest configuration file for DataLakeAnalytics.



---
## Getting Started
To build the SDK for DataLakeAnalytics, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`
---

## Configuration

### Basic Information
These are the global settings for the DataLakeAnalytics API.

``` yaml
openapi-type: data-plane
```

``` yaml $(package-catalog)
tag: package-catalog-2016-11
```

``` yaml $(package-job)
tag: package-job-2017-09-preview
```

### Tag: package-catalog-2016-11

These settings apply only when `--tag=package-catalog-2016-11` is specified on the command line.

``` yaml $(tag) == 'package-catalog-2016-11'
input-file:
- Microsoft.DataLakeAnalytics/stable/2016-11-01/catalog.json
```

### Tag: package-catalog-2015-10-preview

These settings apply only when `--tag=package-catalog-2015-10-preview` is specified on the command line.

``` yaml $(tag) == 'package-catalog-2015-10-preview'
input-file:
- Microsoft.DataLakeAnalytics/preview/2015-10-01-preview/catalog.json
```

### Tag: package-job-2017-09-preview

These settings apply only when `--tag=package-job-2017-09-preview` is specified on the command line.

``` yaml $(tag) == 'package-job-2017-09-preview'
input-file:
- Microsoft.DataLakeAnalytics/preview/2017-09-01-preview/job.json
```

### Tag: package-job-2016-11

These settings apply only when `--tag=package-job-2016-11` is specified on the command line.

``` yaml $(tag) == 'package-job-2016-11'
input-file:
- Microsoft.DataLakeAnalytics/stable/2016-11-01/job.json
```

### Tag: package-job-2016-03-preview

These settings apply only when `--tag=package-job-2016-03-preview` is specified on the command line.

``` yaml $(tag) == 'package-job-2016-03-preview'
input-file:
- Microsoft.DataLakeAnalytics/preview/2016-03-20-preview/job.json
```

### Tag: package-job-2015-11-preview

These settings apply only when `--tag=package-job-2015-11-preview` is specified on the command line.

``` yaml $(tag) == 'package-job-2015-11-preview'
input-file:
- Microsoft.DataLakeAnalytics/preview/2015-11-01-preview/job.json
```

---
# Code Generation

## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  namespace: Microsoft.Azure.Management.DataLake.Analytics
  output-folder: $(csharp-sdks-folder)/DataLake.Analytics/Management.DataLake.Analytics/Generated
batch:
  - package-catalog: true
  - package-job: true
```

## Python

These settings apply only when `--python` is specified on the command line.

```yaml $(python)
python:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  payload-flattening-threshold: 2
  package-name: azure-mgmt-datalake-analytics
  clear-output-folder: true
  no-namespace-folders: true
batch:
  - tag: package-catalog-2016-11
  - tag: package-job-2017-09-preview
```

### Tag: package-job-2017-09-preview and python

These settings apply only when `--tag=package-job-2017-09-preview --python` is specified on the command line.
Please also specify `--python-sdks-folder=<path to the root directory of your azure-sdk-for-python clone>`.

``` yaml $(tag) == 'package-job-2017-09-preview' && $(python)
python:
  namespace: azure.mgmt.datalake.analytics.job
  output-folder: $(python-sdks-folder)/datalake/azure-mgmt-datalake-analytics/azure/mgmt/datalake/analytics/job
```

### Tag: package-catalog-2016-11 and python

These settings apply only when `--tag=package-catalog-2016-11 --python` is specified on the command line.
Please also specify `--python-sdks-folder=<path to the root directory of your azure-sdk-for-python clone>`.

``` yaml $(tag) == 'package-catalog-2016-11' && $(python)
python:
  namespace: azure.mgmt.datalake.analytics.catalog
  output-folder: $(python-sdks-folder)/datalake/azure-mgmt-datalake-analytics/azure/mgmt/datalake/analytics/catalog
```

## Go

See configuration in [readme.go.md](./readme.go.md)

## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
java:
  azure-arm: true
  namespace: com.microsoft.azure.datalake.analytics
  license-header: MICROSOFT_MIT_NO_CODEGEN
  payload-flattening-threshold: 1
  output-folder: $(azure-libraries-for-java-folder)/azure-datalake/analytics
```

### Java multi-api

``` yaml $(java) && $(multiapi)
batch:
  - tag: package-job-2017-09-preview
  - tag: package-catalog-2016-11
  - tag: package-job-2016-11
  - tag: package-job-2016-03-preview
  - tag: package-job-2015-11-preview
  - tag: package-catalog-2015-10-preview
```

# Validation

Since this RP has no unique default package, iterate over all of them for validation:

``` yaml $(validation)
batch:
  - package-catalog: true
  - package-job: true
```

## Multi-API/Profile support for AutoRest v3 generators 

AutoRest V3 generators require the use of `--tag=all-api-versions` to select api files.

This block is updated by an automatic script. Edits may be lost!

``` yaml $(tag) == 'all-api-versions' /* autogenerated */
# include the azure profile definitions from the standard location
require: $(this-folder)/../../../profiles/readme.md

# all the input files across all versions
input-file:
  - $(this-folder)/Microsoft.DataLakeAnalytics/stable/2016-11-01/catalog.json
  - $(this-folder)/Microsoft.DataLakeAnalytics/preview/2015-10-01-preview/catalog.json
  - $(this-folder)/Microsoft.DataLakeAnalytics/preview/2017-09-01-preview/job.json
  - $(this-folder)/Microsoft.DataLakeAnalytics/stable/2016-11-01/job.json
  - $(this-folder)/Microsoft.DataLakeAnalytics/preview/2016-03-20-preview/job.json
  - $(this-folder)/Microsoft.DataLakeAnalytics/preview/2015-11-01-preview/job.json

```

If there are files that should not be in the `all-api-versions` set, 
uncomment the  `exclude-file` section below and add the file paths.

``` yaml $(tag) == 'all-api-versions'
#exclude-file: 
#  - $(this-folder)/Microsoft.Example/stable/2010-01-01/somefile.json
```

