# DNS resolver

> see https://aka.ms/autorest

This is the AutoRest configuration file for DNS resolver.

---

## Getting Started

To build the SDK for DNS resolver, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`

---

## Configuration

### Basic Information

These are the global settings for the DNS resolver API.

``` yaml
openapi-type: arm
tag: package-2022-07
```

### Tag: package-2022-07

These settings apply only when `--tag=package-2022-07` is specified on the command line.

``` yaml $(tag) == 'package-2022-07'
input-file:
  - Microsoft.Network/stable/2022-07-01/dnsresolver.json
```

### Tag: package-2020-04-preview

These settings apply only when `--tag=package-2020-04-preview` is specified on the command line.

``` yaml $(tag) == 'package-2020-04-preview'
input-file:
  - Microsoft.Network/preview/2020-04-01-preview/dnsresolver.json
```

# Code Generation

## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-net-track2
  - repo: azure-sdk-for-python-track2
  - repo: azure-sdk-for-go
  - repo: azure-powershell
```

## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  namespace: Microsoft.Azure.Management.DnsResolver
  payload-flattening-threshold: 2
  output-folder: $(csharp-sdks-folder)/dnsresolver/Microsoft.Azure.Management.DnsResolver/src/Generated
  clear-output-folder: true
```

## Python

See configuration in [readme.python.md](./readme.python.md)

## Go

See configuration in [readme.go.md](./readme.go.md)

## Suppression

``` yaml
directive:
  - where: $.paths
    from: dnsresolver.json
    suppress: OperationsAPIImplementation
    reason: Operation APIs for Microsoft.Network are to be defined in Network swagger.
  - suppress: TrackedResourceListByImmediateParent
    reason: Another list API naming approach is used over the specs.
  - where: $.definitions.Resource
    from: types.json
    suppress: DescriptionAndTitleMissing
    reason: Common types warning.
  - suppress: PreviewVersionOverOneYear
    reason: Preview API version is carried over from limited preview timeframe back in 2021.
  - suppress: PostOperationIdContainsUrlVerb
    reason: A different convention is adopted for naming the POST operations.
```

## Multi-API/Profile support for AutoRest v3 generators

AutoRest V3 generators require the use of `--tag=all-api-versions` to select api files.

This block is updated by an automatic script. Edits may be lost!

``` yaml $(tag) == 'all-api-versions' /* autogenerated */
# include the azure profile definitions from the standard location
# comment until the resolution steps are figured out here.
# require: $(this-folder)/../../../profiles/readme.md

# all the input files across all versions
# input-file:
# - $(this-folder)/Microsoft.Network/preview/2020-04-01-preview/dnsresolver.json

```

If there are files that should not be in the `all-api-versions` set,
uncomment the  `exclude-file` section below and add the file paths.

``` yaml $(tag) == 'all-api-versions'
#exclude-file:
#  - $(this-folder)/Microsoft.Example/stable/2010-01-01/somefile.json
```

