# Mixed-Reality

> see https://aka.ms/autorest

This is the AutoRest configuration file for Mixed-Reality Azure Resource Management.


---

## Getting Started

To build the SDK for Azure Resource Management, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`

---

---

## Configuration

### Basic Information

These are the global settings for the Mixed Reality Azure Resource Management Client.

``` yaml
title: MixedRealityClient
description: Mixed Reality Client
openapi-type: arm
tag: package-2021-03-01-preview
```

### Suppression
``` yaml
directive:
  - suppress: SECRET_PROPERTY
    from:
      - Microsoft.MixedReality/stable/2021-01-01/common.json
    where:
      - $.definitions.AccountKeys.properties.primaryKey
      - $.definitions.AccountKeys.properties.secondaryKey
    reason: Secrets are OK to return in a POST response.
  - suppress: SECRET_PROPERTY
    from:
      - Microsoft.MixedReality/stable/2020-05-01/common.json
    where:
      - $.definitions.AccountKeys.properties.primaryKey
      - $.definitions.AccountKeys.properties.secondaryKey
    reason: Secrets are OK to return in a POST response.
  - suppress: SECRET_PROPERTY
    from:
      - Microsoft.MixedReality/preview/2020-04-06-preview/common.json
    where:
      - $.definitions.AccountKeys.properties.primaryKey
      - $.definitions.AccountKeys.properties.secondaryKey
    reason: Secrets are OK to return in a POST response.
```

``` yaml
directive:
  - suppress: SECRET_PROPERTY
    from:
      - Microsoft.MixedReality/preview/2021-03-01-preview/common.json
    where:
      - $.definitions.AccountKeys.properties.primaryKey
      - $.definitions.AccountKeys.properties.secondaryKey
    reason: Secrets are OK to return in a POST response.
```

### Tag: package-2021-03-01-preview

These settings apply only when `--tag=package-2021-03-01-preview` is specified on the command line.

```yaml $(tag) == 'package-2021-03-01-preview'
input-file:
  - Microsoft.MixedReality/preview/2021-03-01-preview/proxy.json
  - Microsoft.MixedReality/preview/2021-03-01-preview/spatial-anchors.json
  - Microsoft.MixedReality/preview/2021-03-01-preview/remote-rendering.json
  - Microsoft.MixedReality/preview/2021-03-01-preview/object-anchors.json
modelerfour:
  lenient-model-deduplication: true
```

### Tag: package-2021-01

These settings apply only when `--tag=package-2021-01` is specified on the command line.

```yaml $(tag) == 'package-2021-01'
input-file:
  - Microsoft.MixedReality/stable/2021-01-01/proxy.json
  - Microsoft.MixedReality/stable/2021-01-01/spatial-anchors.json
  - Microsoft.MixedReality/stable/2021-01-01/remote-rendering.json
```

### Tag: package-2020-05

These settings apply only when `--tag=package-2020-05` is specified on the command line.

``` yaml $(tag) == 'package-2020-05'
input-file:
- Microsoft.MixedReality/stable/2020-05-01/proxy.json
- Microsoft.MixedReality/stable/2020-05-01/spatial-anchors.json
- Microsoft.MixedReality/preview/2020-04-06-preview/remote-rendering.json
modelerfour:
  lenient-model-deduplication: true
```


### Tag: package-2020-05-01

These settings apply only when `--tag=package-2020-05-01` is specified on the command line.

``` yaml $(tag) == 'package-2020-05-01'
input-file:
- Microsoft.MixedReality/stable/2020-05-01/proxy.json
- Microsoft.MixedReality/stable/2020-05-01/spatial-anchors.json
```

### Tag: package-2020-04-06-preview

These settings apply only when `--tag=package-2020-04-06-preview` is specified on the command line.

``` yaml $(tag) == 'package-2020-04-06-preview'
input-file:
- Microsoft.MixedReality/preview/2020-04-06-preview/proxy.json
- Microsoft.MixedReality/preview/2020-04-06-preview/remote-rendering.json
```

### Tag: package-2019-12-preview

These settings apply only when `--tag=package-2019-12-02-preview` is specified on the command line.

``` yaml $(tag) == 'package-2019-12-02-preview'
input-file:
- Microsoft.MixedReality/preview/2019-12-02-preview/proxy.json
- Microsoft.MixedReality/preview/2019-12-02-preview/remote-rendering.json
- Microsoft.MixedReality/preview/2019-12-02-preview/spatial-anchors.json
```

### Tag: package-2019-02-preview

These settings apply only when `--tag=package-2019-02-preview` is specified on the command line.

``` yaml $(tag) == 'package-2019-02-preview'
input-file:
- Microsoft.MixedReality/preview/2019-02-28-preview/mixedreality.json
```

---

# Code Generation

## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-net
  - repo: azure-sdk-for-python-track2
  - repo: azure-sdk-for-js
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-java
  - repo: azure-resource-manager-schemas
  - repo: azure-powershell
```

## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  azure-arm: true
  payload-flattening-threshold: 1
  license-header: MICROSOFT_MIT_NO_VERSION
  namespace: Microsoft.Azure.Management.MixedReality
  output-folder: $(csharp-sdks-folder)/mixedreality/Microsoft.Azure.Management.MixedReality/src/Generated
  clear-output-folder: true
```

## Python

See configuration in [readme.pyhton.md](./readme.python.md)

## Go

See configuration in [readme.go.md](./readme.go.md)

## Java

See configuration in [readme.java.md](./readme.java.md)


