# Managed Service Identity

> see https://aka.ms/autorest

This is the AutoRest configuration file for Managed Service Identity.

---

## Getting Started

To build the SDK for Managed Service Identity, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`

---

## Configuration

### Basic Information

These are the global settings for the Managed Service Identity API.

``` yaml
openapi-type: arm
tag: package-preview-2022-01
```


### Tag: package-preview-2022-01

These settings apply only when `--tag=package-preview-2022-01` is specified on the command line.

```yaml $(tag) == 'package-preview-2022-01'
input-file:
  - Microsoft.ManagedIdentity/preview/2022-01-31-preview/ManagedIdentity.json
```


### Tag: package-preview-2021-09-30

These settings apply only when `--tag=package-preview-2021-09-30` is specified on the command line.

```yaml $(tag) == 'package-preview-2021-09-30'
input-file:
  - Microsoft.ManagedIdentity/preview/2021-09-30-preview/ManagedIdentity.json
```
### Tag: package-2018-11-30

These settings apply only when `--tag=package-2018-11-30` is specified on the command line.

``` yaml $(tag) == 'package-2018-11-30'
input-file:
- Microsoft.ManagedIdentity/stable/2018-11-30/ManagedIdentity.json
```

### Tag: package-2015-08-31-preview

These settings apply only when `--tag=package-2015-08-31-preview` is specified on the command line.

``` yaml $(tag) == 'package-2015-08-31-preview'
input-file:
- Microsoft.ManagedIdentity/preview/2015-08-31-preview/ManagedIdentity.json
```

## Suppression

``` yaml
directive:
  - suppress: TrackedResourcePatchOperation
    from: ManagedIdentity.json
    where: $.definitions.SystemAssignedIdentity
    reason: The identity type exposed under any scope is not a tracked resource since it is an extension.
  - suppress: RequiredReadOnlySystemData
    reason: User-assigned and system-assigned identities do not support systemData.
```

---

# Code Generation

## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-net
  - repo: azure-sdk-for-python-track2
  - repo: azure-sdk-for-java
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-ruby
    after_scripts:
      - bundle install && rake arm:regen_all_profiles['azure_mgmt_msi']
  - repo: azure-sdk-for-js
  - repo: azure-sdk-for-node
  - repo: azure-resource-manager-schemas
  - repo: azure-powershell
```

## Pyhton

See configuration in [readme.python.md](./readme.python.md)

## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  namespace: Microsoft.Azure.Management.ManagedServiceIdentity
  output-folder: $(csharp-sdks-folder)/managedserviceidentity/Microsoft.Azure.Management.ManagedServiceIdentity/src/Generated
  clear-output-folder: true
```

## Go

See configuration in [readme.go.md](./readme.go.md)

## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
azure-arm: true
fluent: true
namespace: com.microsoft.azure.management.msi
license-header: MICROSOFT_MIT_NO_CODEGEN
payload-flattening-threshold: 1
output-folder: $(azure-libraries-for-java-folder)/azure-mgmt-msi
```

### Java multi-api

``` yaml $(java) && $(multiapi)
batch:
  - tag: package-2018-11-30
  - tag: package-2015-08-31-preview
```

### Tag: package-2018-11-30 and java

These settings apply only when `--tag=package-2018-11-30 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2018-11-30' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.managedserviceidentity.v2018-11-30
  output-folder: $(azure-libraries-for-java-folder)/sdk/managedserviceidentity/mgmt-v2018-11-30
regenerate-manager: true
generate-interface: true
```

### Tag: package-2015-08-31-preview and java

These settings apply only when `--tag=package-2015-08-31-preview --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2015-08-31-preview' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.managedserviceidentity.v2015_08_31_preview
  output-folder: $(azure-libraries-for-java-folder)/sdk/managedserviceidentity/mgmt-v2015_08_31_preview
regenerate-manager: true
generate-interface: true
```
