# OperationalInsightsData

> see https://aka.ms/autorest

This is the AutoRest configuration file for OperationalInsightsData.

---

## Getting Started

To build the SDK for OperationalInsightsData, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`
---

## Configuration

### Basic Information

These are the global settings for the OperationalInsightsData API.

``` yaml
title: OperationalInsightsDataClient
description: Log Analytics Data Plane Client
add-credentials: true
openapi-type: data-plane
tag: v1
```

### Tag: v1

These settings apply only when `--tag=v1` is specified on the command line.

``` yaml $(tag) == 'v1'
input-file:
- Microsoft.OperationalInsights/stable/v1/OperationalInsights.json
directive:
  - reason: Don't expose the GET endpoint since it's behavior is more limited than POST
    remove-operation: Query_Get
```

### Tag: 20171001

``` yaml $(tag) == '20171001'
input-file:
- Microsoft.OperationalInsights/preview/2017-10-01/swagger.json
directive:
  - reason: Rename Query_Post to Query so that we don't get an IQuery interface with 1 operation
    where-operation: Query_Post
    transform: $.operationId = "Query"
```

### Tag: 20210519

``` yaml $(tag) == '20210519'
input-file:
- Microsoft.OperationalInsights/preview/2021-05-19_Preview/OperationalInsights.json
directive:
  - reason: Include batch query and add prefer headers to query request
    where-operation: Query_Post
    transform: $.operationId = "Query"
```

---

# Code Generation

## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

```yaml $(csharp)
csharp:
  namespace: Microsoft.Azure.OperationalInsights
  output-folder: $(csharp-sdks-folder)/operationalinsights/Microsoft.Azure.OperationalInsights/src/Generated
  clear-output-folder: true
  payload-flattening-threshold: 3
directive:
  - from: swagger-document
    where: $.definitions.table.properties.rows.items.items.type
    transform: $ = "object"
```

``` yaml $(python)
python-mode: create
python:
  override-client-name: LogAnalyticsDataClient
  license-header: MICROSOFT_MIT_NO_VERSION
  payload-flattening-threshold: 2
  namespace: azure.loganalytics
  package-name: azure-loganalytics
  package-version: 0.1.0
  clear-output-folder: true
directive:
  - from: swagger-document
    where: $.definitions.table.properties.rows.items.items.type
    transform: $ = "object"
```
``` yaml $(python) && $(python-mode) == 'update'
python:
  no-namespace-folders: true
  output-folder: $(python-sdks-folder)/loganalytics/azure-loganalytics/azure/loganalytics
```
``` yaml $(python) && $(python-mode) == 'create'
python:
  basic-setup-py: true
  output-folder: $(python-sdks-folder)/loganalytics/azure-loganalytics
```

## Go

See configuration in [readme.go.md](./readme.go.md)

## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
java:
  azure-arm: true
  fluent: false
  namespace: com.microsoft.azure.loganalytics
  license-header: MICROSOFT_MIT_NO_CODEGEN
  payload-flattening-threshold: 1
  output-folder: $(azure-libraries-for-java-folder)/loganalytics/data-plane
directive:
  - from: swagger-document
    where: $.definitions.table.properties.rows.items.items.type
    transform: $ = "object"
  ```

## Multi-API/Profile support for AutoRest v3 generators 

AutoRest V3 generators require the use of `--tag=all-api-versions` to select api files.

This block is updated by an automatic script. Edits may be lost!

``` yaml $(tag) == 'all-api-versions' /* autogenerated */
# include the azure profile definitions from the standard location
require: $(this-folder)/../../../profiles/readme.md

# all the input files across all versions
input-file:
  - $(this-folder)/Microsoft.OperationalInsights/stable/v1/OperationalInsights.json
  - $(this-folder)/Microsoft.OperationalInsights/preview/2017-10-01/swagger.json

```

If there are files that should not be in the `all-api-versions` set, 
uncomment the  `exclude-file` section below and add the file paths.

``` yaml $(tag) == 'all-api-versions'
#exclude-file: 
#  - $(this-folder)/Microsoft.Example/stable/2010-01-01/somefile.json
```

